<?php
class DNIEstadoItem{
    const NO_CARGADO = -1;
    const INVALIDO = 0;
    const VALIDO = 1;
    const FALLO_OTRO = 2;
    const FORMATO_INVALIDO = 3;
	const TOKEN_INVALIDO = 100;
    
    var $codigo;
    var $mensaje;
    
    function setCodigo($codigo, $mensaje){
        $this->codigo = $codigo;
        switch ($codigo) {
            case self::INVALIDO:
                $msg = 'DNI invalido.';
                break;
            case self::VALIDO:
                $msg = 'Obtenido satisfactoriamente.';
                break;
            case self::FALLO_OTRO:
                $msg = $mensaje;
                break;
            case self::FORMATO_INVALIDO:
                $msg = 'El formato del DNI es invalido.';
                break;
            case self::TOKEN_INVALIDO:
                $msg = 'Token invalido.';
                break;
                
            default:
                $msg = 'Fallo carga, no hay datos.';
                break;
        }
        $this->mensaje = $msg;
    }
    
}
class DNINacimientoItem{
    const FORMATO_FECHA_AMERICANO = 'm/d/Y';
    const FORMATO_FECHA_HISPANO = 'd/m/Y';
    var $dia;
    var $mes;
    var $ano;
    var $fecha;
    
    function setFecha($dia, $mes, $ano, $formato){
        $this->dia = $dia;
        $this->mes = $mes;
        $this->ano = $ano;
        $this->fecha = date($formato, strtotime("$ano-$mes-$dia"));
    }
}
class DNIDomicilioItem{
    var $direccion;
    var $distrito;
    var $provincia;
    var $departamento;
}
class DNISexoItem{
    const MASCULINO = 1;
    const FEMENINO = 2;
}
class DNINombreItem{
    var $nombres;
    var $apellido_paterno;
    var $apellido_materno;
}
class DNIItem{
    private $dni;
    private $nombre;
    private $sexo;
    private $domicilio;
    private $fecha_nacimiento;
    private $estado;
    private $success = false;
    
    function __construct($dni){
        $this->nombre = new DNINombreItem();
        $this->domicilio = new DNIDomicilioItem();
        $this->fecha_nacimiento = new DNINacimientoItem();
        $this->estado = new DNIEstadoItem();
        
        $this->dni = $dni;
        $this->setEstadoCodigo(DNIEstadoItem::NO_CARGADO);
    }
    
    function setNombre($nombres, $apellido_paterno, $apellido_materno){
        $this->nombre->nombres = $nombres;
        $this->nombre->apellido_paterno = $apellido_paterno;
        $this->nombre->apellido_materno = $apellido_materno;
        
        $this->setEstadoCodigo(DNIEstadoItem::VALIDO);
        $this->success = true;
    }
    
    function setDireccion($direccion){
        $this->domicilio->direccion = $direccion;
    }
    
    function setFechaNacimiento($dia, $mes, $ano, $format=DNINacimientoItem::FORMATO_FECHA_HISPANO){
        $this->fecha_nacimiento->setFecha($dia, $mes, $ano, $format);
    }
    
    function setSexo($sexo){
        $this->sexo = $sexo;
    }
    
    function setDomicilio($direccion, $distrito, $provincia, $departamento){
        $this->domicilio->direccion = $direccion;
        $this->domicilio->distrito = $distrito;
        $this->domicilio->provincia = $provincia;
        $this->domicilio->departamento = $departamento;
    }
    
    function setEstadoCodigo($codigo, $mensaje='Fallo.'){
        $this->estado->setCodigo($codigo, $mensaje);
    }
    
    function getMe(){
        $me = $this->Obj2Array($this);
        $me = json_encode($me);
        return $me;
    }
    
    static private function Obj2Array($_Obj) {
        if (is_object($_Obj))
            $_Obj = get_object_vars($_Obj);
        return(is_array($_Obj) ? array_map(__METHOD__, $_Obj) : $_Obj);
    }
}
class ReniecDNI{

    const url_site = 'https://aplicaciones007.jne.gob.pe/srop_publico/Consulta/api/AfiliadoApi/GetNombresCiudadano';
    
    private $dni;
	
	function __construct($token){
		$this->token = $token;
	}
    private function tokenValido(){
		$tokens = array(
			//master
			'c8e6154863227bd74e986845b1af5f6f',
			//arbio
			'8fcf12fb3a5fe0259d6177e3a435173c',
			//emisem
			'644e7aa6045cb9f3890f30cf972dd401',
			'a19673a29209aa14bd484a2e39b3223a',
			'a4e860bc88d34321264abe1521ad2ddb',
			'd4b245f6361ece7566ae07b6a391bdef',
			'262a87030c80553fb4b49f4670568fc0',
			'430862133f37be7d3914b0b06991087c',
			'dbf5fd06b52d6794910509189b29026e',
			'a0c114c86fc823340a445d4dba42c8dd',
			'dbda10d4c486f074118afd2547f8b90d',
			'2323730e5877b3134eb018e5e52c7b6b',
			'be46a4ef9923408d1789adb7debe2f51',
		);
        return in_array($this->token,$tokens);
    }
    
    function data($url, $post=false, $token=false, $referer=null){
        
        if(empty($referer)) $referer = $url;
        $ch = curl_init ( );
        curl_setopt ( $ch, CURLOPT_REFERER, $referer );
        curl_setopt ( $ch, CURLOPT_USERAGENT, 'Mozilla/5.0 (Windows NT 6.1; WOW64; rv:27.0) Gecko/20100101 Firefox/27.0' );
        curl_setopt ( $ch, CURLOPT_URL, $url );
        curl_setopt ( $ch, CURLOPT_RETURNTRANSFER, 1 );
        curl_setopt ( $ch, CURLOPT_CONNECTTIMEOUT, 8 );
        curl_setopt ( $ch, CURLOPT_COOKIEFILE, dirname(__FILE__).'/cf.txt');
        curl_setopt ( $ch, CURLOPT_COOKIEJAR, dirname(__FILE__).'/cf.txt');
        if( $post ){
            curl_setopt ( $ch, CURLOPT_POST, 1);
            curl_setopt ( $ch, CURLOPT_POSTFIELDS, $post);
        }
        if($token){
            curl_setopt( $ch, CURLOPT_HTTPHEADER,
                array(
                    'Content-Type: application/json;chartset=utf-8',
                    sprintf('RequestVerificationToken: %s',$token)
                )
            );
        }
        $result = curl_exec($ch);
        $error = curl_error($ch);
        curl_close($ch);
        if($result){
            return $result;
        }else{
            return $error;
        }
    }
    
    private function printDNIData($ruc_data){
        header('Content-type: application/json');
        header('Access-Control-Allow-Origin: *');
        die($ruc_data);
    }
	
	function getInfo($dni){
        $dniItem = new DNIItem($dni);
        
        if(!$this->tokenValido()){
            $dniItem->setEstadoCodigo(DNIEstadoItem::TOKEN_INVALIDO);
		}else if(empty($dni)){
            $dniItem->setEstadoCodigo(DNIEstadoItem::INVALIDO);
        }else{
			$apiKeyList = array(
				'e4F3SBpTlc4lsOEZpk408wyICCFgAK6VVnGhdN50wxCl6z65ri4MkXgSWog2',
				'ChAOJMWmbSP96umRCXLkAaIJS1ANRvBfV1EFyMgtCoPu1Db5O55fBwGiLg3R',
				'aTZwwK8KWylmZ2B7IGh4bNB8UEBHmzFJZuse1r0HuBJFXSkIzW0dfqTcoqmF',
				'ck7sEmbMAoh76XeE4J7OWE2skHOIxuVN2cQ7EvVu1M2Gu963EVZspVD0ezKO',
				'5YjMnhXQD09vnrs6mzniIL5qiDgviZPFJvNk9lLdG61pXXqX0nkg5e8ALpUY'
			);
			$apiKey =  $apiKeyList[array_rand($apiKeyList,1)];
            $url = 'https://api.peruapis.com/v1/dni';
            
            $curl = curl_init();
            
            curl_setopt_array($curl, array(
                CURLOPT_URL => $url,
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_ENCODING => '',
                CURLOPT_MAXREDIRS => 10,
                CURLOPT_TIMEOUT => 0,
                CURLOPT_FOLLOWLOCATION => true,
                CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                CURLOPT_CUSTOMREQUEST => 'POST',
                CURLOPT_POSTFIELDS => array('document' => $dni),
                CURLOPT_HTTPHEADER => array(
                    'Authorization: Bearer '.$apiKey,
                    'Accept: application/json'
                ),
            ));
            
            $res = curl_exec($curl);
            curl_close($curl);
            
            $res = json_decode($res,true);
            
            if(!empty($res['success'])){
				$fn = $res['data']['fullname'];
				$dt = explode(' ', $fn);
				$sz = sizeof($dt);
				switch($sz){
					case 3:
						$names = $dt[0];
						$ape_pat = $dt[1];
						$ape_mat = $dt[2];
						break;
					case 4:
						$names = implode(' ',explode(' ', $fn,-2));
						$ape_pat = $dt[2];
						$ape_mat = $dt[3];
						break;
					default:
						if(preg_match('/,/',$fn)){
							preg_match('/\ (),(.*)$/',$fn,$nm);
							$apes = explode(',', $fn)[0];
							$names = trim(explode(',', $fn)[1]);
							$wcapes = explode(' ',$apes);
							if(sizeof($wcapes)==2){
								$ape_pat = $wcapes[0];
								$ape_mat = $wcapes[1];
							}else{
								$ape_pat = implode(' ',explode(' ',$apes,-1));
								$ape_mat = $wcapes[sizeof($wcapes)-1];
							}
						}else{
							$names = implode(' ',explode(' ', $fn,-2));
							$ape_pat = $dt[$sz-2];
							$ape_mat = $dt[$sz-1];
						}
						break;
				}
                $dniItem->setNombre($names, $ape_pat, $ape_mat);
                
                $dniItem->setEstadoCodigo(DNIEstadoItem::VALIDO);
            }else{
                if(!empty($res['errors'])){
                    $dniItem->setEstadoCodigo(DNIEstadoItem::FALLO_OTRO, $res['errors']['document'][0]);
                }else{
                    $dniItem->setEstadoCodigo(DNIEstadoItem::FALLO_OTRO, $res['message']);
                }
            }
        }
        
        $dniObj = $dniItem->getMe();
        $this->printDNIData($dniObj);
    }
}
?>