<?php

class IngresoModel {
    private $pdo;

    function __CONSTRUCT() {
        try {
            $this->pdo = DataBase::ObtenerConexion();
            $this->pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
        } catch (Exception $e) {
            die($e->getMessage());
        }
    }

    public function Listar() {
        try {
            $result = array();
            $stm = $this->pdo->prepare("CALL ingreso_listar(0)");
            $stm->execute();
            foreach ($stm->fetchAll(PDO::FETCH_OBJ) as $r) {
                $result[] = $r;
            }
            return $result;
        } catch (Exception $e) {
            die($e->getMessage());
        }
    }

    public function Buscar($Ingreso_Id) {
        try {
            $result = array();
            $stm = $this->pdo->prepare("CALL ingreso_listar(?)");
            $stm->execute([$Ingreso_Id]);
            foreach ($stm->fetchAll(PDO::FETCH_OBJ) as $r) {
                $result[] = $r;
            }
            return $result;
        } catch (Exception $e) {
            die($e->getMessage());  
        }
    }

    public function ListarxDate($fechaInicio, $fechaFin) {
        try {
            $result = array();
            $stm = $this->pdo->prepare("CALL ingreso_listar_date(?,?)");
            $stm->execute([$fechaInicio, $fechaFin]);
            foreach ($stm->fetchAll(PDO::FETCH_OBJ) as $r) {
                $result[] = $r;
            }
            return $result;
        } catch (Exception $e) {
            die($e->getMessage());
        }
    }

    public function GuardarIngreso($Ingreso) {
        try {
            $Ingreso_Id = 0;
            $stm = $this->pdo->prepare("CALL ingreso_crear(?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,@pIngreso_Id)");
            $stm->execute([
                $Ingreso['dIngFechaInicio'],
                $Ingreso['dIngFechaFin'],
                $Ingreso['nIngCargaFinal'],
                $Ingreso['nIngRetornos'],
                $Ingreso['nIngVentasNetas'],
                $Ingreso['nIngPromociones'],
                $Ingreso['nIngPermisoEfectivo'],
                $Ingreso['nIngTotalPrevisiones'],
                $Ingreso['nIngTotalVarios'],
                $Ingreso['nIngTotalNeto'],
                $Ingreso['nIngCheque'],
                $Ingreso['nIngPorcenComision'],
                $Ingreso['nIngPorcenRetorno'],
                $Ingreso['Usuario_Id'],
                $Ingreso['nIngrEnterprise_Id'],
            ]);
            foreach ($stm->fetchAll(PDO::FETCH_OBJ) as $r) {
                $Ingreso_Id = $r->Ingreso_Id;
            }
            return $Ingreso_Id;
        } catch (Exception $e) {
            die($e->getMessage());
        }
    }

    public function EditarIngreso($Ingreso) {
        try {
            $Ingreso_Id = 0;
            $stm = $this->pdo->prepare("CALL ingreso_editar(?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,@pIngreso_Id)");
            $stm->execute([
                $Ingreso['dIngFechaInicio'],
                $Ingreso['dIngFechaFin'],
                $Ingreso['nIngCargaFinal'],
                $Ingreso['nIngRetornos'],
                $Ingreso['nIngVentasNetas'],
                $Ingreso['nIngPromociones'],
                $Ingreso['nIngPermisoEfectivo'],
                $Ingreso['nIngTotalPrevisiones'],
                $Ingreso['nIngTotalVarios'],
                $Ingreso['nIngTotalNeto'],
                $Ingreso['nIngCheque'],
                $Ingreso['nIngPorcenComision'],
                $Ingreso['nIngPorcenRetorno'],
                $Ingreso['Usuario_Id'],
                $Ingreso['Ingreso_Id'],
                $Ingreso['nIngrEnterprise_Id'],
            ]);
            foreach ($stm->fetchAll(PDO::FETCH_OBJ) as $r) {
                $Ingreso_Id = $r->Ingreso_Id;
            }
            return $Ingreso_Id;
        } catch (Exception $e) {
            die($e->getMessage());
        }
    }

    public function ObtenerDescuentoFijos() {
        try {
            $result = array();
            $stm = $this->pdo->prepare("SELECT * FROM conceptofijo WHERE Concepto_Id <> 1");
            $stm->execute();
            foreach ($stm->fetchAll(PDO::FETCH_OBJ) as $r) {
                $result[] = $r;
            }
            return $result;
        } catch (Exception $e) {
            die($e->getMessage());
        }
    }

    public function GuardarDetalle($detail, $Ingreso_Id) {
        try {
            $stm = $this->pdo->prepare("CALL ingreso_crearDetalle(?,?,?)");
            $stm->execute([
                $detail['Concepto_Id'],
                $Ingreso_Id,
                $detail['nIDMonto'],
            ]);
        } catch (Exception $e) {
            die($e->getMessage());
        }
    }

    public function ListarDetalle($Ingreso_Id) {
        try {
            $result = array();
            $stm = $this->pdo->prepare("CALL ingreso_listarDetalle(?)");
            $stm->execute([$Ingreso_Id]);
            foreach ($stm->fetchAll(PDO::FETCH_OBJ) as $r) {
                $result[] = $r;
            }
            return $result;
        } catch (Exception $e) {
            die($e->getMessage());
        }
    }

    public function EliminarDetalleIngreso($Ingreso_Id) {
        try {
            $stm = $this->pdo->prepare("CALL ingreso_eliminardetalle(?)");
            $stm->execute([$Ingreso_Id]);
        } catch (Exception $e) {
            die($e->getMessage());
        }
    }

    public function EliminarIngreso($Ingreso_Id) {
        try {
            $stm = $this->pdo->prepare("CALL ingreso_eliminar(?)");
            $stm->execute([$Ingreso_Id]);
            return 1;
        } catch (Exception $e) {
            die($e->getMessage());
        }
    }
}